import { IUser } from "aws-cdk-lib/aws-iam";
import { ISecret } from "aws-cdk-lib/aws-secretsmanager";
import { Construct } from "constructs";
export interface SesSmtpCredentialsProps {
    /**
     * The user for which to create an AWS Access Key and to generate the smtp password.
     */
    readonly user: IUser;
    /**
     * Optional, an SecretsManager secret to write the AWS SES Smtp credentials to.
     */
    readonly secret?: ISecret;
}
/**
 * This construct creates an access key for the given user and stores the generated SMTP credentials inside a secret.
 *
 * @example
 *
 * const user = User.fromUserName("ses-user-example");
 * const credentials = new SesSmtpCredentials(this, 'SmtpCredentials', {
 *     user: user,
 * });
 * // credentials.secret
 */
export declare class SesSmtpCredentials extends Construct {
    readonly secret: ISecret;
    constructor(scope: Construct, id: string, props: SesSmtpCredentialsProps);
}
